@@ -146,8 +146,8 @@ impl<'a> Archive<'a> {
 	}
 
 	/// Opens the underlying archive for extracting to the given directory
-	pub async fn extract_to(self, path: &Path) -> Result<OpenArchive, Error> {
-		self.open(OpenMode::Extract, Some(path), Operation::Extract).await
+	pub async fn extract_to(self, path: impl AsRef<Path>) -> Result<OpenArchive, Error> {
+		self.open(OpenMode::Extract, Some(path.as_ref()), Operation::Extract).await
 	}
 
 	/// Opens the underlying archive for testing
@@ -156,7 +156,7 @@ impl<'a> Archive<'a> {
 	}
 
 	/// Opens the underlying archive
-	pub async fn open(self, mode: OpenMode, path: Option<&Path>, operation: Operation) -> Result<OpenArchive, Error> {
+	async fn open(self, mode: OpenMode, path: Option<&Path>, operation: Operation) -> Result<OpenArchive, Error> {
 		OpenArchive::open(&self.filename, mode, self.password, path, operation).await
 	}
 }
